@@ -11,13 +11,15 @@ import os
 import pathlib
 import pyperclip
 import re
+from functools import partial
 
 from humanfriendly import format_timespan
 import pandas as pd
 import ujson
+import fire
 
-from pyxllib.file.specialist import File, Dir
-from pyxllib.debug.specialist import browser, TicToc, Datetime
+from pyxllib.file.specialist import File, Dir, get_etag
+from pyxllib.debug.specialist import browser, TicToc, parse_datetime
 
 
 def _print_df_result(df, outfmt='text'):
@@ -98,6 +100,8 @@ class UtoolsBase:
             if re.match(r'\{.+\}$', self.cmds['subinput']):
                 ext_kwargs = eval(self.cmds['subinput'])
                 self.cmds.update(ext_kwargs)
+        else:
+            self.cmds['subinput'] = ''
 
         self.outfmt = self.cmds['outfmt'] if 'outfmt' in self.cmds else outfmt
 
@@ -161,7 +165,7 @@ class UtoolsFile(UtoolsBase):
         from functools import reduce
         try:
             from xlproject.kzconfig import KzDataSync
-            from pyxllib.data.label import reduce_labelme_jsonfile
+            from pyxllib.data.labelme import reduce_labelme_jsonfile
         except ModuleNotFoundError:
             pass
 
@@ -230,7 +234,7 @@ class UtoolsText(UtoolsBase):
     @clipboard_paste
     def wpath(self):
         """ windows上的路径 """
-        from xlproject.kzpaths import CommonDir
+        from pyxlpr.data.datasets import CommonDir
 
         p = getattr(CommonDir, self.cmds['subinput'])
         # slns比较特别，本地要重定向到D:/slns
@@ -241,7 +245,7 @@ class UtoolsText(UtoolsBase):
     @clipboard_paste
     def upath(self):
         """ unix上的路径 """
-        from xlproject.kzpaths import CommonDir
+        from pyxlpr.data.datasets import CommonDir
 
         p = getattr(CommonDir, self.cmds['subinput'])
         # 因为用了符号链接，实际位置会变回D:/slns，这里需要反向替换下
@@ -251,18 +255,53 @@ class UtoolsText(UtoolsBase):
 
     def wdate(self):
         """ 输入一周的简略日期值 """
+        import datetime
         import pyautogui
 
         start = int(self.cmds['subinput'])
 
+        weektag = '一二三四五六日'
         for i in range(7):
-            dt = Datetime(start) + i
-            pyperclip.copy(dt.strftime('%y%m%d周%k'))
+            dt = parse_datetime(start) + datetime.timedelta(i)
+            pyperclip.copy(dt.strftime('%y%m%d') + f'周{weektag[dt.weekday()]}')
             # pyperclip.paste()  # 这个没用
             # pyautogui.write('210503周一')  # 这个也没用
             pyautogui.hotkey('ctrl', 'v')
             pyautogui.press('down')
 
+    def __win32(self):
+        """ win32相关自动化
+
+        目前主要是word自动化相关的功能，这里有很多demo可以学习怎么用win32做word的自动化
+        """
+        pass
+
+    def browser(self):
+        """ 将内容复制到word，另存为html文件后，用浏览器打开查看 """
+        from pyxllib.robot.win32lib import EnchantWin32WordApplication
+
+        def _func(fmt='html', visible=False, quit=None):
+            """
+            Args:
+                fmt: 输出文件类型
+                    常见的可以简写：html、pdf、txt
+                    其他特殊需求可以用word原变量名：wdFormatDocument
+                visible: 是否展示运行过程，如果不展示，默认最后会close文档
+                quit: 运行完是否退出应用
+            """
+            # 保存的临时文件名采用etag
+            f = File(get_etag(self.cmds['ClipText']), Dir.TEMP, suffix=fmt)
+            app = EnchantWin32WordApplication.get_app(visible=visible)
+            doc = app.new_doc(f)
+            app.Selection.Paste()
+            doc.browser(fmt=fmt)
+            if not visible:
+                doc.Close()  # 关闭 word 文档
+            if quit:
+                app.Quit()
+
+        fire.Fire(_func, self.cmds['subinput'], 'browser')
+
 
 class UtoolsRegex(UtoolsBase):
     def __init__(self, cmds, *, outfmt='text'):
